# About

## OneTool MCP

OneTool is an MCP server that exposes a single `run` tool for LLM code execution. It reduces token usage by 96% compared to traditional MCP setups while maintaining the same accuracy.

## License

OneTool is released under the GPL v3 License.

## Authors

Built by the OneTool team.

## Links

- [GitHub Repository](https://github.com/beycom/onetool-mcp)
- [PyPI Package](https://pypi.org/project/onetool-mcp/)
